package com.akamai.androidsdk.sample;

import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;

import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.app.Activity;
import android.view.Menu;
import android.view.View;
import android.widget.ProgressBar;
import android.widget.SeekBar;
import android.widget.Toast;

// Sample application
// Implements:
// - Events management
// - Playback support for live and vod streams
// - Seeking support 
public class MainActivity extends Activity implements IPlayerEventsListener, SeekBar.OnSeekBarChangeListener
{
	// Video Player object
	private VideoPlayerView mVideoPlayer;
	
	// Progress bar control
	private ProgressBar mProgressBar;
	
	// Seeking bar
	private SeekBar mSeekingBar;
	
	// Media Asset url
	private final String MEDIA_ASSET_URL = "http://devimages.apple.com/iphone/samples/bipbop/bipbopall.m3u8";
	
	// Android SDK License
	private final String ANDROID_SDK_LICENSE = "kiXDwtCwc-XOlx8gdsK8VxkK1KuL4082MNTZ1hHXh-4c1QgGq05vy-6fFC7p12UkN9BPm6awWTGmMiuElpjrFQ==";

	private int mCurrentPosition = 0;
 	private boolean mWasPlaying = false;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        
        // Get a reference to the layout objects
        VideoPlayerContainer videoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        
        // For changing to work in hardware decoding mode 
        videoPlayerContainer.setMode(VideoPlayerContainer.MODE_AUTOMATIC);
        
        mVideoPlayer = videoPlayerContainer.getVideoPlayer();
        mVideoPlayer.setLicense(ANDROID_SDK_LICENSE);
        
        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);
        mSeekingBar = (SeekBar) findViewById(R.id.seekBar);
        
        // Configure controls
        // Set seeking bar listener
        mSeekingBar.setOnSeekBarChangeListener(this);
        
        // Set this object to listen SDK events and start playing the url
        mVideoPlayer.setEventsListener(this);
        mVideoPlayer.playUrl(MEDIA_ASSET_URL);
    }
 
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.activity_main, menu);
        return true;
    }
    
    // SEEKING BAR METHODS
	@Override
	public void onProgressChanged(SeekBar seekBar, int progress,
			boolean fromUser) {
		// TODO Auto-generated method stub
		
	}

	@Override
	public void onStartTrackingTouch(SeekBar seekBar) {
		// TODO Auto-generated method stub
		
	}

	@Override
	public void onStopTrackingTouch(SeekBar seekBar) {
		int position = seekBar.getProgress();
		mVideoPlayer.seek(position, 0);
	}
	 // SEEKING BAR METHODS END
	

    
    // Android SDK Events Handler
	@Override
	public boolean onPlayerEvent(int iInEventType) {
		// Just forward the received event to the UI events handler
		mUIEventsHandler.sendEmptyMessage(iInEventType);
		return true;
	}

	@Override
	public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
	    return true;
		
	}
    // Android SDK Events Handler End
	
	
	// Handler for being sure we are managing events from the UI thread
	public Handler mUIEventsHandler = new Handler()
	{
		@Override 
		public void handleMessage(Message msg)
		{
			switch(msg.what)
			{
			case PLAYER_EVENT_TYPE_START_REBUFFERING:
				mProgressBar.setVisibility(View.VISIBLE);
				break;
				
			case PLAYER_EVENT_TYPE_END_REBUFFERING:
				mProgressBar.setVisibility(View.GONE);
				break;
				
			case PLAYER_EVENT_TYPE_FINISHED:
				break;
			
			case PLAYER_EVENT_TYPE_START_PLAYING:
				mProgressBar.setVisibility(View.GONE);
				mSeekingBar.setVisibility(View.VISIBLE);
				
				// Only allow seeking for vod events
				if(!mVideoPlayer.isLive())
				{
					mSeekingBar.setMax(mVideoPlayer.getDuration());
				}
				else
				{
					mSeekingBar.setMax(100);
					mSeekingBar.setProgress(100);
					mSeekingBar.setEnabled(false);
				}
				break;
				
			case PLAYER_EVENT_TYPE_ERROR:
				mProgressBar.setVisibility(View.GONE);
				Toast.makeText(MainActivity.this, "There was an error while playing the stream", Toast.LENGTH_LONG).show();
				break;
				
			case PLAYER_EVENT_TYPE_POSITION_UPDATE:
				if(!mVideoPlayer.isLive())
				{
					mSeekingBar.setProgress(mVideoPlayer.getTimePosition());
				}
		
				break;
				
			default:
				break;
			}
			
			super.handleMessage(msg);
		}
	};

	@Override
    protected void onPause() 
    {
    	if (mVideoPlayer.isPlaying() || mVideoPlayer.isPaused())
        {
        	mCurrentPosition = mVideoPlayer.getTimePosition();
        	mWasPlaying = true;
        }
    	
        mVideoPlayer.stop();
        super.onPause();
    }

    @Override
    protected void onResume() 
    {
    	if (mWasPlaying)
    	{
    		mVideoPlayer.playUrl(MEDIA_ASSET_URL, mCurrentPosition);
    		mWasPlaying = false;
    	}
    	
        super.onResume();
    }

	@Override
    protected void onDestroy() 
    {	
		mVideoPlayer.stop();
		mVideoPlayer.onDestroy();
        super.onDestroy();
    }
}

	
